/*
 * Copyright (C) 2003 Patrick Reynolds <reynolds@cs.duke.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 *      Free Software Foundation, Inc.
 *      59 Temple Place
 *      Suite 330
 *      Boston, MA 02111-1307
 *      USA
 */

#include <getopt.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "libppm.h"

int main(int argc, char *argv[]) {
	FILE *fp;
  struct ppm_image img;
  int x, y;
	char c;
	int lo=5, hi=250, over=0, under=0;


	while ((c = getopt(argc, argv, "l:h:t:")) != -1) {
		switch (c) {
			case 'l':  lo = atoi(optarg);  break;
			case 'h':  hi = atoi(optarg);  break;
			case 't':  lo = atoi(optarg);  hi = 255-atoi(optarg);  break;
			default:
    		fprintf(stderr, "Usage:\n  %s [-l lo] [-h hi] [-t tol] [file]\n", argv[0]);
				exit(1);
		}
	}

	if (optind < argc) {
		if ((fp = fopen(argv[optind], "r")) != NULL) {
			perror(argv[optind]);
			exit(1);
		}
	}
	else
		fp = stdin;

  if (ppminit(&img) < 0) { fprintf(stderr, "ppminit failed\n"); return -1; }
  if (ppmread(fp, &img) < 0) { fprintf(stderr, "ppmread failed\n"); return -1; }
	for (y=0; y<img.height; y++)
		for (x=0; x<img.width; x++) {
			PEL *p = &PPM_PIXEL(img, x, y, 0);
			if (p[0] >= hi || p[1] >= hi || p[2] >= hi) {
				p[0] = 255;
				p[1] = p[2] = 0;
				over++;
			}
			else if (p[0] <= lo || p[1] <= lo || p[2] <= lo) {
				p[0] = p[1] = 255;
				p[2] = 0;
				under++;
			}
		}
  if (ppmwrite(stdout, &img) < 0) { fprintf(stderr, "ppmwrite failed\n"); return -1; }
  ppmdestroy(&img);

	fprintf(stderr, "%d pixels over-saturated\n", over);
	fprintf(stderr, "%d pixels under-saturated\n", under);

  return (over + under != 0);
}
